@@ -166,6 +166,55 @@ int main(int argc, char *argv[])
 
     }
 
+    //Create the settings folders if they do not exist
+    if(!QFile::exists("portablemode.txt")) {
+        QDir mdir;
+        mdir.mkpath(SETTINGSPATH);
+    }
+
+    //this is stored as base64 so smart git repos
+    //do not complain about shipping a private key.
+    QFile snakeoilKey("://ps.key.base64");
+    QFile snakeoilCert("://ps.pem.base64");
+
+
+    QString defaultCertFile = CERTFILE;
+    QString defaultKeyFile = KEYFILE;
+
+    QFile certfile(defaultCertFile);
+    QFile keyfile(defaultKeyFile);
+    QByteArray decoded;
+    decoded.clear();
+
+    if (!certfile.exists()) {
+        if (snakeoilCert.open(QFile::ReadOnly)) {
+            decoded = QByteArray::fromBase64(snakeoilCert.readAll());
+            snakeoilCert.close();
+        }
+        if (certfile.open(QFile::WriteOnly)) {
+            certfile.write(decoded);
+            certfile.close();
+        }
+    }
+
+    if (!keyfile.exists()) {
+        if (snakeoilKey.open(QFile::ReadOnly)) {
+            decoded = QByteArray::fromBase64(snakeoilKey.readAll());
+            snakeoilKey.close();
+        }
+        if (keyfile.open(QFile::WriteOnly)) {
+            keyfile.write(decoded);
+            keyfile.close();
+        }
+    }
+
+    QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+    if(settings.value("leaveSessionOpen", "").toString().isEmpty()) {
+        settings.setValue("leaveSessionOpen", "false");
+    }
+
+
+
 
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
@@ -282,6 +331,13 @@ int main(int argc, char *argv[])
         QCommandLineOption udpOption(QStringList() << "u" << "udp", "Send UDP.");
         parser.addOption(udpOption);
 
+
+        QCommandLineOption dtlsOption(QStringList() << "dtls", "Send DTLS.");
+        if(PacketNetwork::DTLSisSupported()) {
+            //parser.addOption(dtlsOption);
+            QDEBUG() << "DTLS is not yet supported on DTLS.";
+        }
+
         // A single option with a value
         QCommandLineOption httpOption(QStringList() << "http", "Send HTTP. Allowed values are GET (default) and POST", "http");
         parser.addOption(httpOption);
@@ -339,8 +395,30 @@ int main(int argc, char *argv[])
         }
         bool tcp = parser.isSet(tcpOption);
         bool udp = parser.isSet(udpOption);
+        bool dtls = parser.isSet(dtlsOption);
+
+        if(dtls) {
+            if(!PacketNetwork::DTLSisSupported()) {
+                OUTIF() << "DTLS is not supported in this installation. ";
+                OUTPUT();
+                return -1;
+            }
+        }
+
+
         bool ssl = parser.isSet(sslOption);
         bool sslNoError = parser.isSet(sslNoErrorOption);
+
+        if(ssl) {
+            if(!QSslSocket::supportsSsl()) {
+                OUTIF() << "SSL is not supported in this installation. ";
+                OUTPUT();
+                return -1;
+            }
+        }
+
+
+
         bool ipv6  = parser.isSet(bindIPv6Option);
         bool ipv4  = parser.isSet(bindIPv4Option);
         bool http  = parser.isSet(httpOption);
@@ -498,18 +576,30 @@ int main(int argc, char *argv[])
             ipv6 = false;
             ipv4 = true;
             http = false;
+            dtls = false;
         }
 
 
         if (tcp && udp) {
             OUTIF() << "Warning: both TCP and UDP set. Defaulting to TCP.";
             udp = false;
+            dtls = false;
+        }
+        if (tcp && dtls) {
+            OUTIF() << "Warning: both TCP and DTLS set. Defaulting to TCP.";
+            udp = false;
+            dtls = false;
         }
         if (tcp && ssl) {
             OUTIF() << "Warning: both TCP and SSL set. Defaulting to SSL.";
             tcp = false;
         }
 
+        if (udp && dtls) {
+            OUTIF() << "Warning: both UDP and DTLS set. Defaulting to DTLS.";
+            udp = false;
+        }
+
         if (http && tcp) {
             OUTIF() << "Warning: both HTTP and TCP set. Defaulting to HTTP.";
             tcp = false;
@@ -574,11 +664,11 @@ int main(int argc, char *argv[])
             }
         }
 
-        if (!tcp && !udp && !ssl && !http) {
+        if (!tcp && !udp && !ssl && !http && !dtls) {
             tcp = true;
         }
 
-        if ((tcp || ssl || http) && intense) {
+        if ((tcp || ssl || dtls || http) && intense) {
             OUTIF() << "Warning: Intense Traffic is UDP only.";
         }
 
@@ -587,12 +677,12 @@ int main(int argc, char *argv[])
             tcp = false;
             ssl = false;
             http = false;
+            dtls = false;
         }
 
         QSettings settings(SETTINGSFILE, QSettings::IniFormat);
         bool translateMacroSend = settings.value("translateMacroSendCheck", true).toBool();
 
-
         if(server) {
             bool bindResult = false;
             MainPacketReceiver * receiver = new MainPacketReceiver(nullptr);
@@ -613,24 +703,29 @@ int main(int argc, char *argv[])
             }
 
             QString bindmode = "";
-            if(udp) {
-                bindmode = "UDP";
-                QUdpSocket sock;
-                bindResult = receiver->initUDP(bindIP, bind);
-                bind = receiver->udpSocket->localPort();
-                bindIP = receiver->udpSocket->localAddress().toString();
+            if(dtls) {
+                // TODO: how to set up DTLS server?
             } else {
-                if(tcp) {
-                    bindmode = "TCP";
+                if(udp) {
+                    bindmode = "UDP";
+                    QUdpSocket sock;
+                    bindResult = receiver->initUDP(bindIP, bind);
+                    bind = receiver->udpSocket->localPort();
+                    bindIP = receiver->udpSocket->localAddress().toString();
+                } else {
+                    if(tcp) {
+                        bindmode = "TCP";
+                    }
+                    if(ssl) {
+                        bindmode = "SSL";
+                    }
+                    bindResult = receiver->initSSL(bindIP, bind, ssl);
+                    bind = receiver->tcpServer->serverPort();
+                    bindIP = receiver->tcpServer->serverAddress().toString();
                 }
-                if(ssl) {
-                    bindmode = "SSL";
-                }
-                bindResult = receiver->initSSL(bindIP, bind, ssl);
-                bind = receiver->tcpServer->serverPort();
-                bindIP = receiver->tcpServer->serverAddress().toString();
             }
 
+
             bindIP = bindIP.toUpper();
             if(bindResult) {
                 OUTIF() << bindmode << " Server started on " << bindIP << ":" << bind;
@@ -675,6 +770,7 @@ int main(int argc, char *argv[])
                 ssl = sendPacket.isSSL();
                 tcp = sendPacket.isTCP();
                 udp = sendPacket.isUDP();
+                dtls = sendPacket.isDTLS();
                 http = sendPacket.isHTTP() || sendPacket.isHTTPS();
 
                 if (data.isEmpty() && (!http)) {
@@ -694,14 +790,18 @@ int main(int argc, char *argv[])
                     udp = true;
                     ssl = false;
                     tcp = false;
+                    dtls = false;
                 }
                 if (parser.isSet(tcpOption)) {
                     tcp = true;
                     http = false;
+                    udp = false;
+                    dtls = false;
                 }
                 if (parser.isSet(sslOption)) {
                     ssl = true;
                     tcp = true;
+                    dtls = false;
                     http = false;
                 }
 
@@ -710,6 +810,7 @@ int main(int argc, char *argv[])
                     ssl = false;
                     tcp = false;
                     http = false;
+                    dtls = false;
                 }
             }
 
@@ -758,6 +859,7 @@ int main(int argc, char *argv[])
         QDEBUGVAR(ipv6);
         QDEBUGVAR(tcp);
         QDEBUGVAR(udp);
+        QDEBUGVAR(dtls);
         QDEBUGVAR(ssl);
         QDEBUGVAR(http);
         QDEBUGVAR(sslNoError);
@@ -778,6 +880,14 @@ int main(int argc, char *argv[])
 
         //NOW LETS DO THIS!
 
+        if (dtls && !PacketNetwork::DTLSisSupported()) {
+            OUTIF() << "Error: This computer does not support DTLS.";
+            OUTIF() << "The expected SSL version is " << QSslSocket::sslLibraryBuildVersionString();
+            OUTPUT();
+            return -1;
+        }
+
+
         if (ssl && !QSslSocket::supportsSsl()) {
             OUTIF() << "Error: This computer does not have a native SSL library.";
             OUTIF() << "The expected SSL version is " << QSslSocket::sslLibraryBuildVersionString();
@@ -923,6 +1033,14 @@ int main(int argc, char *argv[])
         recvData.clear();
         int bytesWriten = 0;
 
+
+        if(dtls) {
+            //TODO: How to set up DTLS client?
+
+
+        }
+
+
         if (tcp || ssl) {
             QSslSocket sock;
 
@@ -1038,7 +1156,7 @@ int main(int argc, char *argv[])
                 sock.close();
 
                 OUTPUT();
-                return bytesWriten;
+                return 0;
 
 
             } else {
@@ -1157,7 +1275,7 @@ int main(int argc, char *argv[])
             sock.close();
 
             OUTPUT();
-            return bytesWriten;
+            return 0;
 
         }
 
@@ -1249,24 +1367,9 @@ int main(int argc, char *argv[])
         //Use default OS styling for non-Windows. Too many theme variants.
 
         QSettings settings(SETTINGSFILE, QSettings::IniFormat);
-        bool useDark = settings.value("darkModeCheck", true).toBool();
+        bool useDark = Settings::useDark();
         QString styleSheet = "";
 
-#if QT_VERSION > QT_VERSION_CHECK(6, 5, 0)
-
-        QStyleHints * styleHints = QGuiApplication::styleHints();
-
-        auto colorScheme = styleHints->colorScheme();
-
-        if (colorScheme == Qt::ColorScheme::Dark ) {
-            QDEBUG() << "OS is set to dark mode";
-        }
-
-        if (colorScheme == Qt::ColorScheme::Light ) {
-            QDEBUG() << "OS is set to light mode";
-        }
-#endif
-
         if(useDark) {
             if (file_dark.open(QFile::ReadOnly)) {
                 styleSheet = QLatin1String(file_dark.readAll());
@@ -1287,7 +1390,7 @@ int main(int argc, char *argv[])
 
             QSettings settings(SETTINGSFILE, QSettings::IniFormat);
 
-            bool darkMode = settings.value("darkModeCheck", true).toBool();
+            bool darkMode = Settings::useDark();
             PanelGenerator::darkMode = darkMode;
             PanelGenerator::renderOnly = panels_only;
 
