@@ -2285,7 +2285,7 @@ void MainWindow::on_actionAndroid_App_triggered()
 
 void MainWindow::on_actioniOS_App_triggered()
 {
-    QDesktopServices::openUrl(QUrl("https://packetsender.com/ios"));
+    QDesktopServices::openUrl(QUrl("https://apps.apple.com/app/id1558236648#?platform=iphone"));
 }
 
 
@@ -3005,3 +3005,4 @@ void MainWindow::on_hostName_editingFinished(){
 
 }
 
+
