@@ -35,9 +35,12 @@ public:
     int size();
     void clear();
     void removeFirst();
+    void removeLast();
 
     const QList<Packet> list();
 
+    bool useEllipsis;
+
 
     void prepend(Packet packet);
 private:
