@@ -53,6 +53,9 @@ private:
 };
 #else
 
+#include "mainwindow.h"
+#include <QCheckBox>
+
 
 namespace Ui
 {
@@ -64,7 +67,15 @@ class Settings : public QDialog
         Q_OBJECT
 
     public:
-        explicit Settings(QWidget *parent = nullptr);
+        MainWindow* rmw;
+        QCheckBox* sendSimpleAck;
+        QCheckBox* sendSmartResponse;
+        QLineEdit* sslLocalCertificatePath;
+        QString initialSslLocalCertificatePath;
+        QString initialSslCaPath;
+        QString initialSslPrivateKeyPath;
+
+        explicit Settings(QWidget *parent = nullptr, MainWindow* mw = nullptr);
         ~Settings();
 
         static QStringList defaultPacketTableHeader();
@@ -101,7 +112,10 @@ class Settings : public QDialog
         static bool needLanguage();
         static QString logHeaderTranslate(QString txt);
 
-private slots:
+        static bool useDark();
+    private slots:
+
+
         void on_buttonBox_accepted();
 
         void on_asciiResponseEdit_textEdited(const QString &arg1);
@@ -136,6 +150,7 @@ private slots:
         void on_chooseLanguageButton_clicked();
 
 private:
+        QWidget *parentWidget;
         Ui::Settings *ui;
         QList<Packet> packetsSaved;
         QStringList packetTableHeaders;
@@ -151,7 +166,8 @@ private:
         void deleteHTTPHeader(QString host, QString header);
         void clearHTTPHeaders(QString host);
         static QPair<QString, QString> header2keyvalue(QString header);
-
+    signals:
+        void loadingCertsAgain();
 };
 
 #endif
